@@ -113,6 +113,7 @@ ndim <- function(x)
 permute <- function(x, order, ...)
   UseMethod("permute")
 
+#' @export
 permute.default <- function(x, order, ...)
   .permute_kd(x, order, ...)
 
@@ -234,7 +235,7 @@ permute.hclust <- function(x, order, ...) {
     stop("some permutation vectors do not fit dimension of data")
 
   # check dist
-  if (attr(x, "Diag") || attr(x, "Upper"))
+  if (isTRUE(attr(x, "Diag")) || isTRUE(attr(x, "Upper")))
     stop("'dist' with diagonal or upper triangle matrix not implemented")
 }
 
@@ -267,7 +268,7 @@ permute.hclust <- function(x, order, ...) {
   if (is.character(order))
     order <- seriate(x, method = order, margin = margin, ...)
 
-  .nodots(...)
+  #.nodots(...)
 
   if (!inherits(order, "ser_permutation"))
     order <- ser_permutation(order)
