@@ -51,8 +51,8 @@
 #' @family plots
 #'
 #' @param x a matrix or an object of class \code{dist}.
-#' @param order an object of class \code{ser_permutation}. If \code{NULL} the
-#' order in \code{x} is plotted.
+#' @param order an object of class \code{ser_permutation} or the name of a seriation method.
+#'   If \code{NULL} the order in \code{x} is plotted.
 #' @param col a list of colors used. If \code{NULL}, a gray scale is used (for
 #' matrix larger values are displayed darker and for \code{dist} smaller
 #' distances are darker). For matrices containing logical data, black and white
@@ -68,7 +68,7 @@
 #' @param symkey logical; if \code{x} contains negative values, should the
 #' color palate be symmetric (zero is in the middle)>
 #' @param upper_tri,lower_tri,diag a logical indicating whether to show the
-#' upper triangel, the lower triangle or the diagonal of the (distance) matrix.
+#' upper triangle, the lower triangle or the diagonal of the (distance) matrix.
 #' @param row_labels,col_labels a logical indicating if row and column labels
 #' in \code{x} should be displayed.  If \code{NULL} then labels are displayed
 #' if the \code{x} contains the appropriate dimname and the number of labels is
@@ -79,7 +79,8 @@
 #' @param flip_axes logical; exchange rows and columns for plotting.
 #' @param reverse_columns logical; revers the order of how the columns are
 #' displayed.
-#' @param \dots further arguments are ignored.
+#' @param \dots if `order` is the name of a seriation method then further arguments are  passed
+#'   on to the seriatation method, otherwise they are ignored.
 #' @param newpage,pop,gp Start plot on a new page, pop the viewports after
 #' plotting, and use the supplied \code{gpar} object (see \pkg{grid}).
 #' @returns Nothing.
@@ -87,6 +88,8 @@
 #' @author Christian Buchta and Michael Hahsler
 #' @keywords hplot
 #' @examples
+#' set.seed(1234)
+#'
 #' ## Example: Logical Matrix
 #' x <- matrix(sample(c(FALSE, TRUE), 300, rep = TRUE), ncol = 10,
 #'   dimnames = list(1:30, LETTERS[1:10]))
@@ -354,7 +357,7 @@ pimage.matrix <-
 
     # reorder
     if (!is.null(order))
-      x <- permute(x, order)
+      x <- permute(x, order, ...)
 
     # mask triangles
     if (any(!upper_tri ||
@@ -504,8 +507,18 @@ pimage.matrix <-
       upViewport(down)
   }
 
+#' @export
 pimage.default <- pimage.matrix
 
+# as.matrix does not work for table!
+table2matrix <- function(M)
+  matrix(M, ncol = ncol(M), dimnames = dimnames(M))
+
+#' @rdname pimage
+#' @export
+pimage.table <- function(x, order = NULL, ...)
+  pimage.matrix(table2matrix(x), order = order, ...)
+
 ## small values are dark
 #' @rdname pimage
 #' @export
@@ -541,7 +554,7 @@ pimage.dist <-
       prop <- TRUE
 
     if (!is.null(order))
-      x <- permute(x, order)
+      x <- permute(x, order, ...)
 
     if (flip_axes) warning("flip_axes has no effect for distance matrices.")
 
